/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { ITelemetryBaseLogger } from "@fluidframework/common-definitions";
import { IRequest } from "@fluidframework/core-interfaces";
import { ILocationRedirectionError, IUrlResolver } from "@fluidframework/driver-definitions";
/**
 * Checks if the error is location redirection error.
 * @param error - error whose type is to be determined.
 * @returns - True is the error is location redirection error.
 */
export declare function isLocationRedirectionError(error: any): error is ILocationRedirectionError;
/**
 * Handles location redirection while fulfilling the loader request.
 * @param api - Callback in which user can wrap the loader.resolve or loader.request call.
 * @param request - request to be resolved.
 * @param urlResolver - resolver used to resolve the url.
 * @param baseLogger - logger to send events.
 * @returns - Response from the api call.
 */
export declare function resolveWithLocationRedirectionHandling<T>(api: (request: IRequest) => Promise<T>, request: IRequest, urlResolver: IUrlResolver, baseLogger?: ITelemetryBaseLogger): Promise<T>;
//# sourceMappingURL=resolveWithLocationRedirection.d.ts.map